==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/CascadegrantrevokeaccessrecordstrackerCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Cascadegrantrevokeaccessrecordstracker;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.CascadegrantrevokeaccessrecordstrackerRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.FileattachmentRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class CascadegrantrevokeaccessrecordstrackerCollectionRequest extends CollectionPageEntityRequest<Cascadegrantrevokeaccessrecordstracker, CascadegrantrevokeaccessrecordstrackerRequest>{

    protected ContextPath contextPath;

    public CascadegrantrevokeaccessrecordstrackerCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Cascadegrantrevokeaccessrecordstracker.class, cp -> new CascadegrantrevokeaccessrecordstrackerRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest cascadegrantrevokeaccessrecordstracker_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest cascadegrantrevokeaccessrecordstracker_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest cascadegrantrevokeaccessrecordstracker_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest cascadegrantrevokeaccessrecordstracker_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest cascadegrantrevokeaccessrecordstracker_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest cascadegrantrevokeaccessrecordstracker_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest cascadegrantrevokeaccessrecordstracker_FileAttachments() {
        return new FileattachmentCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest cascadegrantrevokeaccessrecordstracker_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/CascadegrantrevokeaccessrecordstrackerCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Cascadegrantrevokeaccessrecordstracker;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.CascadegrantrevokeaccessrecordstrackerRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.FileattachmentRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class CascadegrantrevokeaccessrecordstrackerCollectionRequest extends CollectionPageEntityRequest<Cascadegrantrevokeaccessrecordstracker, CascadegrantrevokeaccessrecordstrackerRequest>{

    protected ContextPath contextPath;

    public CascadegrantrevokeaccessrecordstrackerCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Cascadegrantrevokeaccessrecordstracker.class, cp -> new CascadegrantrevokeaccessrecordstrackerRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest cascadegrantrevokeaccessrecordstracker_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest cascadegrantrevokeaccessrecordstracker_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest cascadegrantrevokeaccessrecordstracker_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest cascadegrantrevokeaccessrecordstracker_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest cascadegrantrevokeaccessrecordstracker_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest cascadegrantrevokeaccessrecordstracker_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest cascadegrantrevokeaccessrecordstracker_FileAttachments() {
        return new FileattachmentCollectionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest cascadegrantrevokeaccessrecordstracker_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

}
